<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for searchAbonnementRequest StructType
 * Meta informations extracted from the WSDL
 * - documentation: Zoeken van abonnements informatie.
 * @subpackage Structs
 */
class SearchAbonnementRequest extends AbstractStructBase
{
    /**
     * The requestTag
     * Meta informations extracted from the WSDL
     * - documentation: Vrij veld voor aanroepende partij. De inhoud van dit veld wordt altijd identiek teruggestuurd.
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * - maxLength: 4000
     * @var string
     */
    public $requestTag;
    /**
     * The postcode
     * Meta informations extracted from the WSDL
     * - documentation: Postcode. Er mag gezocht worden met een combinatie van cijfers, en geen of 1 letter (bijv. 1100 K, of 1100). De service zoekt dan o.b.v. een LIKE.
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * - maxLength: 10
     * @var string
     */
    public $postcode;
    /**
     * The huisNummer
     * Meta informations extracted from the WSDL
     * - documentation: Huisnummer.
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * - totalDigits: 38
     * @var float
     */
    public $huisNummer;
    /**
     * The huisNummerToevoeging
     * Meta informations extracted from the WSDL
     * - documentation: Huisnummer toevoeging Match wordt uitgevoerd zonder spaties, ?-? en op uppercase.
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * - maxLength: 12
     * @var string
     */
    public $huisNummerToevoeging;
    /**
     * The achternaam
     * Meta informations extracted from the WSDL
     * - documentation: Achternaam van de relatie Indien meegegeven wordt de match uitgevoerd op uppercase en o.b.v. de 1e 5 karakters.
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * - maxLength: 120
     * @var string
     */
    public $achternaam;
    /**
     * The email
     * Meta informations extracted from the WSDL
     * - documentation: Email-adres van de relatie Indien meegegegeven wordt de match 1-op-1 uitgevoerd.
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * - maxLength: 80
     * @var string
     */
    public $email;
    /**
     * The telefoonNummer
     * Meta informations extracted from the WSDL
     * - documentation: Telefoonnummer Indien meegegeven wordt de match 1-op-1 uitgevoerd.
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * - maxLength: 80
     * @var string
     */
    public $telefoonNummer;
    /**
     * The toonAbonnementen
     * Meta informations extracted from the WSDL
     * - documentation: Welk type abonnementen moet worden getoond 0=Alleen gewone (default) 1=Alleen licentie 2=Alle abonnementen.
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * - totalDigits: 38
     * @var float
     */
    public $toonAbonnementen;
    /**
     * The relNo
     * Meta informations extracted from the WSDL
     * - documentation: Relatienummer Indien meegegegeven wordt de match 1-op-1 uitgevoerd.
     * - maxOccurs: 1
     * - minOccurs: 0
     * - nillable: true
     * - totalDigits: 15
     * @var int
     */
    public $relNo;
    /**
     * Constructor method for searchAbonnementRequest
     * @uses SearchAbonnementRequest::setRequestTag()
     * @uses SearchAbonnementRequest::setPostcode()
     * @uses SearchAbonnementRequest::setHuisNummer()
     * @uses SearchAbonnementRequest::setHuisNummerToevoeging()
     * @uses SearchAbonnementRequest::setAchternaam()
     * @uses SearchAbonnementRequest::setEmail()
     * @uses SearchAbonnementRequest::setTelefoonNummer()
     * @uses SearchAbonnementRequest::setToonAbonnementen()
     * @uses SearchAbonnementRequest::setRelNo()
     * @param string $requestTag
     * @param string $postcode
     * @param float $huisNummer
     * @param string $huisNummerToevoeging
     * @param string $achternaam
     * @param string $email
     * @param string $telefoonNummer
     * @param float $toonAbonnementen
     * @param int $relNo
     */
    public function __construct($requestTag = null, $postcode = null, $huisNummer = null, $huisNummerToevoeging = null, $achternaam = null, $email = null, $telefoonNummer = null, $toonAbonnementen = null, $relNo = null)
    {
        $this
            ->setRequestTag($requestTag)
            ->setPostcode($postcode)
            ->setHuisNummer($huisNummer)
            ->setHuisNummerToevoeging($huisNummerToevoeging)
            ->setAchternaam($achternaam)
            ->setEmail($email)
            ->setTelefoonNummer($telefoonNummer)
            ->setToonAbonnementen($toonAbonnementen)
            ->setRelNo($relNo);
    }
    /**
     * Get requestTag value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return string|null
     */
    public function getRequestTag()
    {
        return isset($this->requestTag) ? $this->requestTag : null;
    }
    /**
     * Set requestTag value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param string $requestTag
     * @return \StructType\SearchAbonnementRequest
     */
    public function setRequestTag($requestTag = null)
    {
        // validation for constraint: maxLength
        if ((is_scalar($requestTag) && strlen($requestTag) > 4000) || (is_array($requestTag) && count($requestTag) > 4000)) {
            throw new \InvalidArgumentException(sprintf('Invalid length, please provide an array with 4000 element(s) or a scalar of 4000 character(s) at most, "%d" length given', is_scalar($requestTag) ? strlen($requestTag) : count($requestTag)), __LINE__);
        }
        // validation for constraint: string
        if (!is_null($requestTag) && !is_string($requestTag)) {
            throw new \InvalidArgumentException(sprintf('Invalid value, please provide a string, "%s" given', gettype($requestTag)), __LINE__);
        }
        if (is_null($requestTag) || (is_array($requestTag) && empty($requestTag))) {
            unset($this->requestTag);
        } else {
            $this->requestTag = $requestTag;
        }
        return $this;
    }
    /**
     * Get postcode value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return string|null
     */
    public function getPostcode()
    {
        return isset($this->postcode) ? $this->postcode : null;
    }
    /**
     * Set postcode value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param string $postcode
     * @return \StructType\SearchAbonnementRequest
     */
    public function setPostcode($postcode = null)
    {
        // validation for constraint: maxLength
        if ((is_scalar($postcode) && strlen($postcode) > 10) || (is_array($postcode) && count($postcode) > 10)) {
            throw new \InvalidArgumentException(sprintf('Invalid length, please provide an array with 10 element(s) or a scalar of 10 character(s) at most, "%d" length given', is_scalar($postcode) ? strlen($postcode) : count($postcode)), __LINE__);
        }
        // validation for constraint: string
        if (!is_null($postcode) && !is_string($postcode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value, please provide a string, "%s" given', gettype($postcode)), __LINE__);
        }
        if (is_null($postcode) || (is_array($postcode) && empty($postcode))) {
            unset($this->postcode);
        } else {
            $this->postcode = $postcode;
        }
        return $this;
    }
    /**
     * Get huisNummer value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return float|null
     */
    public function getHuisNummer()
    {
        return isset($this->huisNummer) ? $this->huisNummer : null;
    }
    /**
     * Set huisNummer value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param float $huisNummer
     * @return \StructType\SearchAbonnementRequest
     */
    public function setHuisNummer($huisNummer = null)
    {
        // validation for constraint: totalDigits
        if (is_float($huisNummer) && strlen(str_replace(array(' ', '.', ',', '-', '+'), '', $huisNummer)) !== 38) {
            throw new \InvalidArgumentException(sprintf('Invalid value, the value must at most contain 38 digits, "%d" given', strlen(substr($huisNummer, strpos($huisNummer, '.')))), __LINE__);
        }
        if (is_null($huisNummer) || (is_array($huisNummer) && empty($huisNummer))) {
            unset($this->huisNummer);
        } else {
            $this->huisNummer = $huisNummer;
        }
        return $this;
    }
    /**
     * Get huisNummerToevoeging value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return string|null
     */
    public function getHuisNummerToevoeging()
    {
        return isset($this->huisNummerToevoeging) ? $this->huisNummerToevoeging : null;
    }
    /**
     * Set huisNummerToevoeging value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param string $huisNummerToevoeging
     * @return \StructType\SearchAbonnementRequest
     */
    public function setHuisNummerToevoeging($huisNummerToevoeging = null)
    {
        // validation for constraint: maxLength
        if ((is_scalar($huisNummerToevoeging) && strlen($huisNummerToevoeging) > 12) || (is_array($huisNummerToevoeging) && count($huisNummerToevoeging) > 12)) {
            throw new \InvalidArgumentException(sprintf('Invalid length, please provide an array with 12 element(s) or a scalar of 12 character(s) at most, "%d" length given', is_scalar($huisNummerToevoeging) ? strlen($huisNummerToevoeging) : count($huisNummerToevoeging)), __LINE__);
        }
        // validation for constraint: string
        if (!is_null($huisNummerToevoeging) && !is_string($huisNummerToevoeging)) {
            throw new \InvalidArgumentException(sprintf('Invalid value, please provide a string, "%s" given', gettype($huisNummerToevoeging)), __LINE__);
        }
        if (is_null($huisNummerToevoeging) || (is_array($huisNummerToevoeging) && empty($huisNummerToevoeging))) {
            unset($this->huisNummerToevoeging);
        } else {
            $this->huisNummerToevoeging = $huisNummerToevoeging;
        }
        return $this;
    }
    /**
     * Get achternaam value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return string|null
     */
    public function getAchternaam()
    {
        return isset($this->achternaam) ? $this->achternaam : null;
    }
    /**
     * Set achternaam value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param string $achternaam
     * @return \StructType\SearchAbonnementRequest
     */
    public function setAchternaam($achternaam = null)
    {
        // validation for constraint: maxLength
        if ((is_scalar($achternaam) && strlen($achternaam) > 120) || (is_array($achternaam) && count($achternaam) > 120)) {
            throw new \InvalidArgumentException(sprintf('Invalid length, please provide an array with 120 element(s) or a scalar of 120 character(s) at most, "%d" length given', is_scalar($achternaam) ? strlen($achternaam) : count($achternaam)), __LINE__);
        }
        // validation for constraint: string
        if (!is_null($achternaam) && !is_string($achternaam)) {
            throw new \InvalidArgumentException(sprintf('Invalid value, please provide a string, "%s" given', gettype($achternaam)), __LINE__);
        }
        if (is_null($achternaam) || (is_array($achternaam) && empty($achternaam))) {
            unset($this->achternaam);
        } else {
            $this->achternaam = $achternaam;
        }
        return $this;
    }
    /**
     * Get email value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return string|null
     */
    public function getEmail()
    {
        return isset($this->email) ? $this->email : null;
    }
    /**
     * Set email value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param string $email
     * @return \StructType\SearchAbonnementRequest
     */
    public function setEmail($email = null)
    {
        // validation for constraint: maxLength
        if ((is_scalar($email) && strlen($email) > 80) || (is_array($email) && count($email) > 80)) {
            throw new \InvalidArgumentException(sprintf('Invalid length, please provide an array with 80 element(s) or a scalar of 80 character(s) at most, "%d" length given', is_scalar($email) ? strlen($email) : count($email)), __LINE__);
        }
        // validation for constraint: string
        if (!is_null($email) && !is_string($email)) {
            throw new \InvalidArgumentException(sprintf('Invalid value, please provide a string, "%s" given', gettype($email)), __LINE__);
        }
        if (is_null($email) || (is_array($email) && empty($email))) {
            unset($this->email);
        } else {
            $this->email = $email;
        }
        return $this;
    }
    /**
     * Get telefoonNummer value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return string|null
     */
    public function getTelefoonNummer()
    {
        return isset($this->telefoonNummer) ? $this->telefoonNummer : null;
    }
    /**
     * Set telefoonNummer value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param string $telefoonNummer
     * @return \StructType\SearchAbonnementRequest
     */
    public function setTelefoonNummer($telefoonNummer = null)
    {
        // validation for constraint: maxLength
        if ((is_scalar($telefoonNummer) && strlen($telefoonNummer) > 80) || (is_array($telefoonNummer) && count($telefoonNummer) > 80)) {
            throw new \InvalidArgumentException(sprintf('Invalid length, please provide an array with 80 element(s) or a scalar of 80 character(s) at most, "%d" length given', is_scalar($telefoonNummer) ? strlen($telefoonNummer) : count($telefoonNummer)), __LINE__);
        }
        // validation for constraint: string
        if (!is_null($telefoonNummer) && !is_string($telefoonNummer)) {
            throw new \InvalidArgumentException(sprintf('Invalid value, please provide a string, "%s" given', gettype($telefoonNummer)), __LINE__);
        }
        if (is_null($telefoonNummer) || (is_array($telefoonNummer) && empty($telefoonNummer))) {
            unset($this->telefoonNummer);
        } else {
            $this->telefoonNummer = $telefoonNummer;
        }
        return $this;
    }
    /**
     * Get toonAbonnementen value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return float|null
     */
    public function getToonAbonnementen()
    {
        return isset($this->toonAbonnementen) ? $this->toonAbonnementen : null;
    }
    /**
     * Set toonAbonnementen value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param float $toonAbonnementen
     * @return \StructType\SearchAbonnementRequest
     */
    public function setToonAbonnementen($toonAbonnementen = null)
    {
        // validation for constraint: totalDigits
        if (is_float($toonAbonnementen) && strlen(str_replace(array(' ', '.', ',', '-', '+'), '', $toonAbonnementen)) !== 38) {
            throw new \InvalidArgumentException(sprintf('Invalid value, the value must at most contain 38 digits, "%d" given', strlen(substr($toonAbonnementen, strpos($toonAbonnementen, '.')))), __LINE__);
        }
        if (is_null($toonAbonnementen) || (is_array($toonAbonnementen) && empty($toonAbonnementen))) {
            unset($this->toonAbonnementen);
        } else {
            $this->toonAbonnementen = $toonAbonnementen;
        }
        return $this;
    }
    /**
     * Get relNo value
     * An additional test has been added (isset) before returning the property value as
     * this property may have been unset before, due to the fact that this property is
     * removable from the request (nillable=true+minOccurs=0)
     * @return int|null
     */
    public function getRelNo()
    {
        return isset($this->relNo) ? $this->relNo : null;
    }
    /**
     * Set relNo value
     * This property is removable from request (nillable=true+minOccurs=0), therefore
     * if the value assigned to this property is null, it is removed from this object
     * @param int $relNo
     * @return \StructType\SearchAbonnementRequest
     */
    public function setRelNo($relNo = null)
    {
        // validation for constraint: totalDigits
        if (is_float($relNo) && strlen(str_replace(array(' ', '.', ',', '-', '+'), '', $relNo)) !== 15) {
            throw new \InvalidArgumentException(sprintf('Invalid value, the value must at most contain 15 digits, "%d" given', strlen(substr($relNo, strpos($relNo, '.')))), __LINE__);
        }
        // validation for constraint: int
        if (!is_null($relNo) && !is_numeric($relNo)) {
            throw new \InvalidArgumentException(sprintf('Invalid value, please provide a numeric value, "%s" given', gettype($relNo)), __LINE__);
        }
        if (is_null($relNo) || (is_array($relNo) && empty($relNo))) {
            unset($this->relNo);
        } else {
            $this->relNo = $relNo;
        }
        return $this;
    }
    /**
     * Method called when an object has been exported with var_export() functions
     * It allows to return an object instantiated with the values
     * @see AbstractStructBase::__set_state()
     * @uses AbstractStructBase::__set_state()
     * @param array $array the exported values
     * @return \StructType\SearchAbonnementRequest
     */
    public static function __set_state(array $array)
    {
        return parent::__set_state($array);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
